# Changelog

## 0.22.0 (2026-02-04)

Full Changelog: [v0.21.0...v0.22.0](https://github.com/zavudev/sdk-python/compare/v0.21.0...v0.22.0)

### Features

* **api:** api update ([6fceacb](https://github.com/zavudev/sdk-python/commit/6fceacb65de6d9c8229e66e27d3d0c7b214684ff))
* **api:** api update ([08c1d9e](https://github.com/zavudev/sdk-python/commit/08c1d9eaa44e3a9ca2b952ea38ba28d4ad3d416f))
* **api:** api update ([048c987](https://github.com/zavudev/sdk-python/commit/048c987a5ddb5abf311456de72c2cb060271f7c3))
* **client:** add custom JSON encoder for extended type support ([60767c0](https://github.com/zavudev/sdk-python/commit/60767c0f65814fa4cb3f3666c0d8d2f7ee0674d4))


### Bug Fixes

* **docs:** fix mcp installation instructions for remote servers ([9a62f07](https://github.com/zavudev/sdk-python/commit/9a62f07bda3f2b2eebe22d57257408ece37e0303))


### Chores

* **ci:** upgrade `actions/github-script` ([c29efb3](https://github.com/zavudev/sdk-python/commit/c29efb3d32ffa4d70f63841efc51028dc73103e6))

## 0.21.0 (2026-01-21)

Full Changelog: [v0.20.0...v0.21.0](https://github.com/zavudev/sdk-python/compare/v0.20.0...v0.21.0)

### Features

* **api:** api update ([fc3a194](https://github.com/zavudev/sdk-python/commit/fc3a1940a50660a55b6c926e254fb6ff94a332cc))

## 0.20.0 (2026-01-17)

Full Changelog: [v0.19.0...v0.20.0](https://github.com/zavudev/sdk-python/compare/v0.19.0...v0.20.0)

### Features

* **api:** api update ([6998197](https://github.com/zavudev/sdk-python/commit/6998197ad56cee88c9a59b84f62e277fa5d2af74))
* **client:** add support for binary request streaming ([0005048](https://github.com/zavudev/sdk-python/commit/00050480bc677325704fb30af40819c0e0f93d4e))


### Chores

* **internal:** update `actions/checkout` version ([e57abb1](https://github.com/zavudev/sdk-python/commit/e57abb153176d4c1c7d407bc071c4a4bc1e8f813))

## 0.19.0 (2026-01-13)

Full Changelog: [v0.18.0...v0.19.0](https://github.com/zavudev/sdk-python/compare/v0.18.0...v0.19.0)

### Features

* **api:** api update ([94cfa25](https://github.com/zavudev/sdk-python/commit/94cfa25f3ceacf01eb442386568d2a30a6794334))
* **api:** api update ([4bbeef9](https://github.com/zavudev/sdk-python/commit/4bbeef90e44a848c0b21d82fc47e50924afb58e9))

## 0.18.0 (2026-01-11)

Full Changelog: [v0.17.1...v0.18.0](https://github.com/zavudev/sdk-python/compare/v0.17.1...v0.18.0)

### Features

* **api:** api update ([404dbe6](https://github.com/zavudev/sdk-python/commit/404dbe68e1643b3a139a1e564a81e632b2af3d61))
* **api:** api update ([d5ccd5d](https://github.com/zavudev/sdk-python/commit/d5ccd5d3258a9417f20e59eec9dd9c5975e3a523))

## 0.17.1 (2026-01-06)

Full Changelog: [v0.17.0...v0.17.1](https://github.com/zavudev/sdk-python/compare/v0.17.0...v0.17.1)

### Documentation

* prominently feature MCP server setup in root SDK readmes ([2fa3b9f](https://github.com/zavudev/sdk-python/commit/2fa3b9f6fc37f20107e16d175cb1c4ff3001e8fb))

## 0.17.0 (2026-01-01)

Full Changelog: [v0.16.0...v0.17.0](https://github.com/zavudev/sdk-python/compare/v0.16.0...v0.17.0)

### Features

* **api:** api update ([27d05ff](https://github.com/zavudev/sdk-python/commit/27d05ff6c679e8b3bff99a47c069dc93d793bec7))


### Chores

* configure new SDK language ([504527d](https://github.com/zavudev/sdk-python/commit/504527d59118dbf0a88a4f9af1a8dc38e1d8f6ea))

## 0.16.0 (2025-12-28)

Full Changelog: [v0.15.0...v0.16.0](https://github.com/zavudev/sdk-python/compare/v0.15.0...v0.16.0)

### Features

* **api:** manual updates ([16a98cf](https://github.com/zavudev/sdk-python/commit/16a98cfecffa5c3a97f46997d00cad79383b8a0c))

## 0.15.0 (2025-12-25)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/zavudev/sdk-python/compare/v0.14.0...v0.15.0)

### Features

* **api:** api update ([9667eb3](https://github.com/zavudev/sdk-python/commit/9667eb3ba34bf4a0a4be96aa8613056c5d6bc2de))

## 0.14.0 (2025-12-21)

Full Changelog: [v0.13.1...v0.14.0](https://github.com/zavudev/sdk-python/compare/v0.13.1...v0.14.0)

### Features

* **api:** api update ([6e140ca](https://github.com/zavudev/sdk-python/commit/6e140caf1465a60925fcf925c7e4ea39dad31916))


### Chores

* **internal:** add `--fix` argument to lint script ([24b14b7](https://github.com/zavudev/sdk-python/commit/24b14b78710431593ac3c6a2c31602c7c763bf2d))

## 0.13.1 (2025-12-18)

Full Changelog: [v0.13.0...v0.13.1](https://github.com/zavudev/sdk-python/compare/v0.13.0...v0.13.1)

### Bug Fixes

* use async_to_httpx_files in patch method ([fd7fa37](https://github.com/zavudev/sdk-python/commit/fd7fa377fd75e062bfce0bd2cfc39b2ae044c9e1))


### Chores

* speedup initial import ([1974163](https://github.com/zavudev/sdk-python/commit/1974163ab7d6f1fef84437d535052acf468d9aed))


### Refactors

* **internal:** switch from rye to uv ([f862b5a](https://github.com/zavudev/sdk-python/commit/f862b5a3ccad3ad9a662646cd09de543f282fa85))

## 0.13.0 (2025-12-17)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/zavudev/sdk-python/compare/v0.12.0...v0.13.0)

### Features

* **api:** api update ([1f7ee8c](https://github.com/zavudev/sdk-python/commit/1f7ee8ce8cf2a6a3cb662bdddba1279ca916d1d1))
* **api:** whatsapp profile ([beb8348](https://github.com/zavudev/sdk-python/commit/beb834894c1b86c9bfe69783ad4ebb0648e3b7d6))

## 0.12.0 (2025-12-16)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/zavudev/sdk-python/compare/v0.11.0...v0.12.0)

### Features

* **api:** add submit template ([32c5e78](https://github.com/zavudev/sdk-python/commit/32c5e78d0a44385429346db509d4ea5e345afb76))
* **api:** api update ([f00a45c](https://github.com/zavudev/sdk-python/commit/f00a45c4fced1fa32e133ed21b55e23bde611522))
* **api:** api update ([d33336f](https://github.com/zavudev/sdk-python/commit/d33336f7de3862a588decdd3d7ef15c9fadd90d2))


### Chores

* **internal:** add missing files argument to base client ([08b5b97](https://github.com/zavudev/sdk-python/commit/08b5b97210d16560efde81ba335e09a0c3daebf9))

## 0.11.0 (2025-12-16)

Full Changelog: [v0.10.1...v0.11.0](https://github.com/zavudev/sdk-python/compare/v0.10.1...v0.11.0)

### Features

* **api:** api update ([bb8af00](https://github.com/zavudev/sdk-python/commit/bb8af003e952918262b8502959de28520de6ed10))
* **api:** api update ([39a0632](https://github.com/zavudev/sdk-python/commit/39a0632944c04190ccaf8b56db9dc245d758c5c6))
* **api:** api update ([69c25f3](https://github.com/zavudev/sdk-python/commit/69c25f337070ddc7756fe61a6324f1b1d4eb2dd8))
* **api:** api update ([575e5ea](https://github.com/zavudev/sdk-python/commit/575e5eaa04124422b74f4268410f010a37908c6e))
* **api:** manual updates ([8fedeac](https://github.com/zavudev/sdk-python/commit/8fedeac87ef5a5f1b6fa9781e9cfbbe80a50ab74))

## 0.10.1 (2025-12-09)

Full Changelog: [v0.10.0...v0.10.1](https://github.com/zavudev/sdk-python/compare/v0.10.0...v0.10.1)

### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([0d56717](https://github.com/zavudev/sdk-python/commit/0d567178f18a477dac78609555ef0f6dab4224cb))


### Chores

* add missing docstrings ([bcf0eda](https://github.com/zavudev/sdk-python/commit/bcf0eda247ab50b911f732856086515807097919))

## 0.10.0 (2025-12-08)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/zavudev/sdk-python/compare/v0.9.0...v0.10.0)

### Features

* **api:** phone numbers api ([689817d](https://github.com/zavudev/sdk-python/commit/689817dfba15320cedb52d3ce0c6e8a64b306c7d))

## 0.9.0 (2025-12-05)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/zavudev/sdk-python/compare/v0.8.0...v0.9.0)

### Features

* **api:** fix other issues ([3781480](https://github.com/zavudev/sdk-python/commit/37814808c411e815ec43ac8e1d6b3e9a24fdddf1))

## 0.8.0 (2025-12-05)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/zavudev/sdk-python/compare/v0.7.0...v0.8.0)

### Features

* **api:** manual updates ([b7ef995](https://github.com/zavudev/sdk-python/commit/b7ef99530baeebdb87ebe99c19cee1a92302a8ec))

## 0.7.0 (2025-12-05)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/zavudev/sdk-python/compare/v0.6.0...v0.7.0)

### Features

* **api:** fix pagination ([3e6f37a](https://github.com/zavudev/sdk-python/commit/3e6f37aefd021bb8f78757f611e0d572c87a7cc4))

## 0.6.0 (2025-12-04)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/zavudev/sdk-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([b2ee9d4](https://github.com/zavudev/sdk-python/commit/b2ee9d4c470aa17f0ea17787a16e98053abb3cee))

## 0.5.0 (2025-12-04)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/zavudev/sdk-python/compare/v0.4.0...v0.5.0)

### Features

* **api:** update api docs ([cfcb99d](https://github.com/zavudev/sdk-python/commit/cfcb99d2bacb8f7a3362cf6fc859c270e60321b2))


### Chores

* update SDK settings ([d4d7d58](https://github.com/zavudev/sdk-python/commit/d4d7d58b5f6a5fa85061444fb89b8b9e0c25c0be))

## 0.4.0 (2025-12-04)

Full Changelog: [v0.0.1...v0.4.0](https://github.com/zavudev/sdk-python/compare/v0.0.1...v0.4.0)

### Features

* add github ([da0ecc7](https://github.com/zavudev/sdk-python/commit/da0ecc7146bd4afb80b6e20a503383055d636a32))
* fixes ([757385d](https://github.com/zavudev/sdk-python/commit/757385d5eac1135805974118f5f9d0f23f0f10e6))


### Chores

* sync repo ([2dcaa60](https://github.com/zavudev/sdk-python/commit/2dcaa608c20687cc067e10e2f0b2762e248c7fef))
* update SDK settings ([6989bfd](https://github.com/zavudev/sdk-python/commit/6989bfd96bf1ac9b3afc37b2d0decdfa8b3ebfd0))
